@@ -29,12 +29,12 @@ from pre_workbench.guihelper import showWidgetDlg, filledColorIcon, makeWidgetDl
 from pre_workbench.syshelper import get_current_rss
 
 
-def showSettingsDlg(definition, values=None, title: str="Options", parent=None, ok_callback=None, min_width=400):
+def showSettingsDlg(definition, values=None, title: str="Options", parent=None, ok_callback=None, min_width=400, help_callback=None):
 	if values == None: values = {}
 	sg = SettingsGroup(definition, values)
-	return showWidgetDlg(sg, title, lambda: values, parent, ok_callback, min_width)
+	return showWidgetDlg(sg, title, lambda: values, parent, ok_callback, min_width, help_callback)
 
-def showPreferencesDlg(definition, values=None, title: str="Preferences", parent=None, ok_callback=None):
+def showPreferencesDlg(definition, values=None, title: str="Preferences", parent=None, ok_callback=None, help_callback=None):
 	if values == None: values = {}
 
 	tabWidget = QTabWidget()
@@ -53,9 +53,9 @@ def showPreferencesDlg(definition, values=None, title: str="Preferences", parent
 		tab.layout().addWidget(sg)
 
 	tabWidget.setMinimumWidth(600)
-	return showWidgetDlg(tabWidget, title, lambda: values, parent, ok_callback)
+	return showWidgetDlg(tabWidget, title, lambda: values, parent, ok_callback, help_callback)
 
-def showListSelectDialog(listOptions: List[Tuple[Any, str]], selectedOption, title: str="Select ...", parent=None, ok_callback=None, multiselect=False):
+def showListSelectDialog(listOptions: List[Tuple[Any, str]], selectedOption, title: str="Select ...", parent=None, ok_callback=None, multiselect=False, help_callback=None):
 	widget = QListWidget()
 	for value, text in listOptions:
 		w = QListWidgetItem(text, widget)
@@ -67,7 +67,7 @@ def showListSelectDialog(listOptions: List[Tuple[Any, str]], selectedOption, tit
 		retval_callback = lambda: [item.data(1000) for item in widget.selectedItems()]
 	else:
 		retval_callback = lambda: widget.currentItem().data(1000)
-	dlg, box = makeWidgetDlg(widget, title, retval_callback, parent, ok_callback)
+	dlg, box = makeWidgetDlg(widget, title, retval_callback, parent, ok_callback, help_callback)
 	widget.itemDoubleClicked.connect(box.accepted.emit)
 	if dlg.exec() == QDialog.Rejected: return None
 	if not ok_callback: return retval_callback()
