@@ -24,11 +24,13 @@ import weakref
 import shlex
 from copy import deepcopy
 
+import yaml
 from PyQt5 import QtCore
 from PyQt5.QtCore import pyqtSignal, QUrl
-from PyQt5.QtGui import QDesktopServices, QColor
+from PyQt5.QtGui import QDesktopServices, QColor, QKeySequence
 from PyQt5.QtWidgets import QFileSystemModel, QTreeView, QWidget, QVBoxLayout, QAbstractItemView, QMenu, \
-	QAction, QListWidget, QListWidgetItem, QTreeWidget, QTreeWidgetItem, QTextEdit, QToolBar, QComboBox, QMessageBox
+	QAction, QListWidget, QListWidgetItem, QTreeWidget, QTreeWidgetItem, QTextEdit, QToolBar, QComboBox, QMessageBox, \
+	QShortcut, QFileDialog
 
 import pre_workbench.app
 from pre_workbench import configs
@@ -37,13 +39,13 @@ from pre_workbench.configs import getIcon, SettingsField
 from pre_workbench.controls.genericwidgets import showSettingsDlg
 from pre_workbench.controls.scintillaedit import showScintillaDialog
 from pre_workbench.errorhandler import ConsoleWindowLogHandler
-from pre_workbench.guihelper import filledColorIcon, getMonospaceFont, runProcessWithDlg, qApp, TODO
+from pre_workbench.guihelper import filledColorIcon, getMonospaceFont, runProcessWithDlg, APP, TODO
 from pre_workbench.app import navigate
 from pre_workbench.macros.macro import Macro
 from pre_workbench.rangetree import RangeTreeWidget
 from pre_workbench.structinfo.parsecontext import AnnotatingParseContext
 from pre_workbench.windows.content.textfile import ScintillaEdit
-from pre_workbench.typeeditor import JsonView
+from pre_workbench.typeeditor import JsonView, showTypeEditorDlg
 from pre_workbench.typeregistry import WindowTypes, DockWidgetTypes
 from pre_workbench.util import PerfTimer, truncate_str
 
@@ -385,8 +387,9 @@ class RangeListWidget(QWidget):
 				# TODO ...on click: self.selectRange(d)
 
 
-@DockWidgetTypes.register(title="Macros", icon="regular-expression-search-match.png", dock="Right", showFirstRun=False)
+@DockWidgetTypes.register(title="Macros", icon="scripts.png", dock="Right", showFirstRun=False)
 class MacroListDockWidget(QWidget):
+	option_types=["-","text","color","font","select","check","int"]
 	CONTAINER_ROLE = QtCore.Qt.UserRole + 100
 	MACRO_NAME_ROLE = QtCore.Qt.UserRole + 101
 	def __init__(self):
@@ -409,8 +412,8 @@ class MacroListDockWidget(QWidget):
 
 	def _loadList(self):
 		self.treeView.clear()
-		for title, container in qApp().macro_containers.items():
-			root = QTreeWidgetItem(self.treeView, [title])
+		for container_id, container in APP().macro_containers.items():
+			root = QTreeWidgetItem(self.treeView, [container.containerTitle])
 			root.setExpanded(True)
 			root.setData(0, MacroListDockWidget.CONTAINER_ROLE, container)
 			self._loadMacros(root, container)
@@ -433,16 +436,19 @@ class MacroListDockWidget(QWidget):
 				if container.macrosEditable:
 					ctx.addAction("Edit code", lambda: self.editCode(container.getMacro(macroname)))
 					ctx.addAction("Preferences", lambda: self.editPreferences(container.getMacro(macroname)))
+					ctx.addAction("Edit options", lambda: self.editOptions(container.getMacro(macroname)))
 					ctx.addAction("Delete macro", lambda: self.deleteMacro(container, macroname))
 				else:
 					ctx.addAction("View code", lambda: self.editCode(container.getMacro(macroname)))
 				ctx.addSeparator()
-				for title, target_container in qApp().macro_containers.items():
+				for target_container_id, target_container in APP().macro_containers.items():
 					if target_container.macrosEditable and target_container != container:
-						ctx.addAction("Copy to " + title, lambda trg=target_container: self.copyMacro(container.getMacro(macroname), trg))
+						ctx.addAction("Copy to " + target_container.containerTitle, lambda trg=target_container: self.copyMacro(container.getMacro(macroname), trg))
+				ctx.addAction("Export ...", lambda: self.exportMacro(container.getMacro(macroname)))
 			else:
 				if container.macrosEditable:
 					ctx.addAction("Create macro ...", lambda: self.createMacro(container))
+					ctx.addAction("Import ...", lambda: self.importMacro(container))
 			ctx.exec(self.treeView.viewport().mapToGlobal(point))
 
 	def deleteMacro(self, container, macroname):
@@ -461,12 +467,32 @@ class MacroListDockWidget(QWidget):
 		else:
 			TODO()
 
-	def editPreferences(self, macro):
-		result = showSettingsDlg([
+	def exportMacro(self, macro):
+		fileName, _ = QFileDialog.getSaveFileName(self, "Export Macro", os.path.join(APP().project.projectFolder, macro.name + ".macro.yml"), "Macro (*.macro.yml)")
+		if not fileName: return
+		with open(fileName, "w") as f:
+			yaml.dump({"name": macro.name, "input_type": macro.input_type, "output_type": macro.output_type, "options": macro.options, "metadata": macro.metadata, "code": macro.code},
+						   f, explicit_start=True, sort_keys=False)
+
+	def importMacro(self, container):
+		fileName, _ = QFileDialog.getOpenFileName(self, "Import Macro",
+												  APP().project.projectFolder,
+												  "Macro (*.macro.yml);;All files (*.*)")
+		if not fileName: return
+		with open(fileName, "r") as f:
+			x = yaml.safe_load(f)
+			macro = Macro(container, x["name"], x["input_type"], x["output_type"], x["code"], x["options"], x["metadata"], None)
+			self.editPreferences(macro)
+
+	MacroPreferencesDef = [
 			SettingsField("name", "Name", "text", {}),
-			SettingsField("input_type", "Input Type", "select", {"options": zip(Macro.TYPES, Macro.TYPES)}),
-			SettingsField("output_type", "Output Type", "select", {"options": zip(Macro.TYPES, Macro.TYPES)}),
-		], {"name": macro.name, "input_type": macro.input_type, "output_type": macro.output_type}, title="Edit Preferences Of Macro \"" + macro.name + "\"", parent=self)
+			SettingsField("input_type", "Macro/Input Type", "select", {"options": list(zip(Macro.TYPES, Macro.TYPES))}),
+			SettingsField("output_type", "Output Type", "select", {"options": list(zip(Macro.TYPES, Macro.TYPES))}),
+		]
+	def editPreferences(self, macro):
+		result = showSettingsDlg(MacroListDockWidget.MacroPreferencesDef,
+								 {"name": macro.name, "input_type": macro.input_type, "output_type": macro.output_type},
+								 title="Edit Preferences Of Macro \"" + macro.name + "\"", parent=self)
 		if not result: return
 		macro.name = result["name"]
 		macro.input_type = result["input_type"]
@@ -475,11 +501,7 @@ class MacroListDockWidget(QWidget):
 		self._loadList()
 
 	def createMacro(self, container):
-		result = showSettingsDlg([
-			SettingsField("name", "Name", "text", {}),
-			SettingsField("input_type", "Input Type", "select", {"options": zip(Macro.TYPES, Macro.TYPES)}),
-			SettingsField("output_type", "Output Type", "select", {"options": zip(Macro.TYPES, Macro.TYPES)}),
-		], title="Create Macro ...", parent=self)
+		result = showSettingsDlg(MacroListDockWidget.MacroPreferencesDef, title="Create Macro ...", parent=self)
 		if not result: return
 		macro = Macro(container, result["name"], result["input_type"], result["output_type"], "", [], {}, None)
 		container.storeMacro(macro)
@@ -487,11 +509,9 @@ class MacroListDockWidget(QWidget):
 		self._loadList()
 
 	def copyMacro(self, macro, target_container):
-		result = showSettingsDlg([
-			SettingsField("name", "Name", "text", {}),
-			SettingsField("input_type", "Input Type", "select", {"options": zip(Macro.TYPES, Macro.TYPES)}),
-			SettingsField("output_type", "Output Type", "select", {"options": zip(Macro.TYPES, Macro.TYPES)}),
-		], {"name": macro.name, "input_type": macro.input_type, "output_type": macro.output_type}, title="Copy Macro ...", parent=self)
+		result = showSettingsDlg(MacroListDockWidget.MacroPreferencesDef,
+								 {"name": macro.name, "input_type": macro.input_type, "output_type": macro.output_type},
+								 title="Copy Macro ...", parent=self)
 		if not result: return
 		new_macro = Macro(target_container, result["name"], result["input_type"], result["output_type"], macro.code, deepcopy(macro.options), deepcopy(macro.metadata), None)
 		target_container.storeMacro(new_macro)
@@ -509,6 +529,18 @@ class MacroListDockWidget(QWidget):
 			hash = hashlib.sha256(res.encode('utf-8')).digest()
 			configs.updateMru("TrustedMacroHashes", hash, 255)
 
+	def editOptions(self, macro):
+		verb = "Edit" if macro.container.macrosEditable else "View"
+		from PyQt5.Qsci import QsciLexerYAML
+		options = [{"id":x["id"], "title":x["title"], "field": [ MacroListDockWidget.option_types.index(x["fieldType"]), x["params"] ]} for x in macro.options]
+		res = showTypeEditorDlg("settingsgroup.tes", "SettingsGroup", options, verb + " Options Of Macro \""+macro.name+"\"", )
+		if res:
+			if macro.container.macrosEditable:
+				#macro.options = yaml.safe_load(res)
+				macro.options = [{"id":x["id"], "title":x["title"], "fieldType": MacroListDockWidget.option_types[x["field"][0]], "params": x["field"][1]} for x in res]
+				print(macro.options)
+				macro.container.storeMacro(macro)
+
 
 
 @DockWidgetTypes.register(title="Selection Heuristics", icon="table-select-cells.png")
@@ -639,14 +671,14 @@ class ExtToolDockWidget(QWidget):
 		toolbar = QToolBar()
 		toolbar.addAction("Run", self._runTool)
 		self.cmdLineEdit = QComboBox(editable=True, minimumWidth=200)
+		QShortcut(QKeySequence(QtCore.Qt.Key_Return), self.cmdLineEdit, activated=self._runTool, context=QtCore.Qt.WidgetWithChildrenShortcut)
 		self._updateMru()
 		toolbar.addWidget(self.cmdLineEdit)
-		self.treeView = QTreeWidget()
-		self.treeView.setColumnCount(1)
-		self.treeView.setColumnWidth(1, 300)
+		self.textBox = QTextEdit()
+		self.textBox.setFont(getMonospaceFont())
 		windowLayout = QVBoxLayout()
 		windowLayout.addWidget(toolbar)
-		windowLayout.addWidget(self.treeView)
+		windowLayout.addWidget(self.textBox)
 		windowLayout.setContentsMargins(0,0,0,0)
 		self.setLayout(windowLayout)
 
@@ -661,7 +693,7 @@ class ExtToolDockWidget(QWidget):
 		commandLine = self.cmdLineEdit.currentText()
 		configs.updateMru("ExtToolMru", commandLine, 10)
 		self._updateMru()
-		self.treeView.clear()
+		self.textBox.clear()
 		if not self.selBytes: return
 		f = tempfile.NamedTemporaryFile(delete=False)
 		try:
@@ -670,9 +702,10 @@ class ExtToolDockWidget(QWidget):
 			args = commandLine.format('"' + f.name + '"')
 			result = runProcessWithDlg("External command", "Running external command: " + args[0], self,
 									   args=args, stdin=subprocess.DEVNULL, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True)
-			for line in result['stdout'].decode('latin1').split('\n'):
-				root = QTreeWidgetItem(self.treeView)
-				root.setText(0, line)
+			self.textBox.setText(result['stdout'].decode('latin1'))
+			#for line in result['stdout'].decode('latin1').split('\n'):
+			#	root = QTreeWidgetItem(self.treeView)
+			#	root.setText(0, line)
 		finally:
 			os.remove(f.name)
 
@@ -689,6 +722,7 @@ class SearchDockWidget(QWidget):
 		toolbar = QToolBar()
 		toolbar.addAction("Find", self._runTool)
 		self.cmdLineEdit = QComboBox(editable=True, minimumWidth=200)
+		QShortcut(QKeySequence(QtCore.Qt.Key_Return), self.cmdLineEdit, activated=self._runTool, context=QtCore.Qt.WidgetWithChildrenShortcut)
 		self._updateMru()
 		toolbar.addWidget(self.cmdLineEdit)
 		self.treeView = QTreeWidget()
